package Test::cpan::versioning;

our $VERSION = '1.00';

=pod

=head1 NAME

Test::cpan::versioning - Testing how CPAN uploader treats non-standard version

=head1 DESCRIPTION

I'm going to test v1.00, 1.001, 1.2, etc to see how safe it is to release 2-, 3, 4 digit
versions without compromising the incremental monotonicity

=cut

1;


